@@ -42,6 +42,8 @@ Further updates:
 
 =item * version 0.93, published on September 25, 2006
 
+=item * version 0.94, published on October 2, 2006
+
 =back
 
 =head1 SEE ALSO
@@ -363,6 +365,7 @@ ARTICLE
 ARTO
 ARTURAZ
 ARUNBEAR
+ARUTEIDO
 ARVIEGAS
 ARVINDPR
 ARYEH
@@ -2669,6 +2672,7 @@ JURL
 JUSTVIT
 JV
 JVANASCO
+JVASILE
 JVB
 JVBSOFT
 JVENIER
@@ -2768,6 +2772,7 @@ KESTER
 KESZLER
 KETHGEN
 KEVINA
+KEVINFINK
 KEVINJ
 KEVINR
 KEVINRICE
@@ -2813,6 +2818,7 @@ KJOHNSON
 KJWCODE
 KKRON
 KLBLNGMJ
+KLEINJ
 KLIMKIN
 KLLIN
 KLOHNER
@@ -4423,6 +4429,7 @@ SAMV
 SANBEG
 SANDERSON
 SANFACE
+SANJIT
 SANTU
 SAPA
 SAPAPO
